uniform bool doShading;
uniform vec3 eyePosition;
varying vec3 eyeDirectionFS, lightDirectionFS, normalDirectionFS;
varying vec4 ambientLightColor, diffuseLightColor;
   
void main(void)
{
	gl_Position = ftransform();
	gl_TexCoord[0] = gl_MultiTexCoord0;

	vec4 vertexPosition = gl_Vertex;

	vec3 eyeDirection  = normalize(eyePosition - vertexPosition.xyz);
	vec3 lightDirection = normalize(gl_LightSource[0].spotDirection.xyz);

	vec3 normalDirection = gl_NormalMatrix * gl_Normal;
	vec3 tangentDirection = gl_NormalMatrix * gl_MultiTexCoord1.xyz;
	vec3 binormalDirection = cross(normalDirection, tangentDirection);
	  
	eyeDirectionFS.x = dot(tangentDirection, eyeDirection);
	eyeDirectionFS.y = dot(binormalDirection, eyeDirection);
	eyeDirectionFS.z = dot(normalDirection, eyeDirection);

	lightDirectionFS.x = dot(tangentDirection, lightDirection.xyz);
	lightDirectionFS.y = dot(binormalDirection, lightDirection.xyz);
	lightDirectionFS.z = dot(normalDirection, lightDirection.xyz);
	
	normalDirectionFS.x = dot(tangentDirection, normalDirection.xyz);
	normalDirectionFS.y = dot(binormalDirection, normalDirection.xyz);
	normalDirectionFS.z = dot(normalDirection, normalDirection.xyz);

	if (doShading)
		ambientLightColor = gl_LightSource[0].ambient;
	else
		ambientLightColor = vec4(1.0,1.0,1.0,1.0);
	diffuseLightColor = gl_LightSource[0].diffuse;
}